@@ -177,14 +177,21 @@ class TimestreamLoader(TimestreamReader):
         accepted_records, rejected_records = records, []
         try:
             common_att = {
-                    'Dimensions': common_dimensions.loadable(),
-                    'MeasureValueType': 'DOUBLE',
-                    'Time': str(capture_time_ms),
-                    'Version': 1
-                }
+                'MeasureValueType': 'DOUBLE',
+                'Time': str(capture_time_ms),
+                'Version': 1
+            }
             if is_multi:
-                common_att['MeasureName'] = source
+                common_att['MeasureName'] = source or 'multi-measure'
                 common_att['MeasureValueType'] = 'MULTI'
+                if 'source' in common_dimensions.get_dimension_keys():
+                    # Remove the source dimension
+                    # Source becomes MeasureName as stated above
+                    common_dimensions.remove_dimension('source')
+                common_att['Dimensions'] = common_dimensions.loadable()
+            else:
+                common_att['Dimensions'] = common_dimensions.loadable()
+
             _ = self._timestream_write_client.write_records(
                 DatabaseName=self.__database_name,
                 TableName=self.__table_name,
@@ -210,13 +217,16 @@ class TimestreamLoader(TimestreamReader):
         accepted_records, rejected_records = records, []
         try:
             common_att = {
-                    'MeasureValueType': 'DOUBLE',
-                    'Version': self._current_time_ms
-                }
+                'MeasureValueType': 'DOUBLE',
+                'Version': self._current_time_ms
+            }
             if is_multi:
-                common_att['MeasureName'] = source
+                common_att['MeasureName'] = source or 'multi-measure'
                 common_att['MeasureValueType'] = 'MULTI'
-                common_dimensions.pop('source', None) #source becomes MeasureName as stated 2 lines up
+                if 'source' in common_dimensions.get_dimension_keys():
+                    # Remove the source dimension
+                    # Source becomes MeasureName as stated above
+                    common_dimensions.remove_dimension('source')
                 common_att['Dimensions'] = common_dimensions.loadable()
             else:
                 common_att['Dimensions'] = common_dimensions.loadable()
